==> neptune_ui-2.1.0.77.jar: com/tandbergtv/neptune/ui/realm/client/RealmComponentPermissions.java <==
/*
 * Created on May 23, 2010
 * 
 * (C) Copyright TANDBERG Television Inc.
 */

package com.tandbergtv.neptune.ui.realm.client;

/**
 * Maintains the permission names
 * 
 * @author Vijay Silva
 */
public final class RealmComponentPermissions {

	/* Cannot instantiate */
	private RealmComponentPermissions() {
	}

	/**
	 * User View permission name
	 */
	public static final String USER_VIEW = "UserManagement_View";

	/**
	 * User Create permission name
	 */
	public static final String USER_CREATE = "UserManagement_Create";

	/**
	 * User Modify permission name
	 */
	public static final String USER_MODIFY = "UserManagement_Modify";

	/**
	 * User Delete permission name
	 */
	public static final String USER_DELETE = "UserManagement_Delete";

	/**
	 * Role View permission name
	 */
	public static final String ROLE_VIEW = "RoleManagement_View";

	/**
	 * Role Create permission name
	 */
	public static final String ROLE_CREATE = "RoleManagement_Create";

	/**
	 * Role Modify permission name
	 */
	public static final String ROLE_MODIFY = "RoleManagement_Modify";

	/**
	 * Role Delete permission name
	 */
	public static final String ROLE_DELETE = "RoleManagement_Delete";
	
	/**
	 * Role Delete permission name
	 */
	public static final String BC_MODIFY = "BC_Administer";
	
	/**
	 * Settings View permission name
	 */
	public static final String SETTINGS_VIEW = "SettingsManagement_View";

	/**
	 * Settings Modify permission name
	 */
	public static final String SETTINGS_MODIFY = "SettingsManagement_Modify";

}

==> neptune_ui-6.0.0.6.jar: com/tandbergtv/neptune/ui/realm/client/RealmComponentPermissions.java <==
/*
 * Created on May 23, 2010
 * 
 * (C) Copyright TANDBERG Television Inc.
 */

package com.tandbergtv.neptune.ui.realm.client;

/**
 * Maintains the permission names
 * 
 * @author Vijay Silva
 */
public final class RealmComponentPermissions {

	/* Cannot instantiate */
	private RealmComponentPermissions() {
	}

	/**
	 * User View permission name
	 */
	public static final String USER_VIEW = "UserManagement_View";

	/**
	 * User Create permission name
	 */
	public static final String USER_CREATE = "UserManagement_Create";

	/**
	 * User Modify permission name
	 */
	public static final String USER_MODIFY = "UserManagement_Modify";

	/**
	 * User Delete permission name
	 */
	public static final String USER_DELETE = "UserManagement_Delete";

	/**
	 * Role View permission name
	 */
	public static final String ROLE_VIEW = "RoleManagement_View";

	/**
	 * Role Create permission name
	 */
	public static final String ROLE_CREATE = "RoleManagement_Create";

	/**
	 * Role Modify permission name
	 */
	public static final String ROLE_MODIFY = "RoleManagement_Modify";

	/**
	 * Role Delete permission name
	 */
	public static final String ROLE_DELETE = "RoleManagement_Delete";
	
	/**
	 * Role Delete permission name
	 */
	public static final String BC_MODIFY = "BC_Administer";
	
	/**
	 * Settings View permission name
	 */
	public static final String SETTINGS_VIEW = "SettingsManagement_View";

	/**
	 * Settings Modify permission name
	 */
	public static final String SETTINGS_MODIFY = "SettingsManagement_Modify";
		
	/**
	 * Action items view permission name
	 */
	public static final String ACTION_ITEMS_VIEW = "ActionItemsManagement_View";
	
	/**
	 * Action items permission name for performing the recovery options fix
	 */
	public static final String ACTION_ITEMS_FIX = "ActionItemsManagement_Fix";

}
